@@ -5,6 +5,7 @@ function (x, y, tau = 0.5, method = "sfn", rhs = NULL, control, ...)
     else tau <- 0.5
     fit <- switch(method,
 	sfn = rq.fit.sfn(x, y, tau = tau,  rhs = rhs, control = control, ...),
+	lasso = rq.fit.sfn(x, y, tau = tau,  rhs = rhs, control = control, ...),
         sfnc = rq.fit.sfnc(x, y, tau = tau,  rhs = rhs, control = control, ...), {
             what <- paste("rq.fit.", method, sep = "")
             if (exists(what, mode = "function"))
@@ -595,7 +596,7 @@ predict.qss2 <- function (object, newdata, ...)
         b[1] <- tri.area(v[c(4, 2, 3), ])/Area
         b[2] <- tri.area(v[c(1, 4, 3), ])/Area
         b[3] <- tri.area(v[c(1, 2, 4), ])/Area
-        if (any(b < 0 || b > 1)) 
+        if (any(b < 0) || any(b > 1)) 
             stop("barycentric snafu")
         b
     }
@@ -799,7 +800,19 @@ resid.rqss <- function(object, ...) object$resid[1:object$n]
             X <- X * weights
             Y <- Y * weights
         }
-        fit <- rqss.fit(X, Y, tau = tau,  rhs = rhs, control = control, ...)
+	XpX <- t(X) %*% X
+        nnzdmax <- XpX@ia[length(XpX@ia)] - 1
+        if (is.null(control[["nsubmax"]]))
+            control[["nsubmax"]] <- max(nnzdmax, floor(1000 +
+                exp(-1.6) * nnzdmax^1.2))
+        if (is.null(control[["nnzlmax"]]))
+            control[["nnzlmax"]] <- floor(2e+05 - 2.8 * nnzdmax +
+                7e-04 * nnzdmax^2)
+        if (is.null(control[["tmpmax"]]))
+            control[["tmpmax"]] <- floor(1e+05 + exp(-12.1) *
+                nnzdmax^2.35)
+        fit <- rqss.fit(X, Y, tau = tau,  rhs = rhs, control = control, 
+			method = method, ...)
         fit$nrA <- nrA
     }
     names(fit$coef) <- vnames
@@ -848,10 +861,7 @@ resid.rqss <- function(object, ...) object$resid[1:object$n]
     n <- length(resid) - nrL - nrA[m]
     uhat <- resid[1:n]
     h <- bandwidth.rq(tau, n, hs = TRUE)
-    if(tau + h > 1)
-       stop("tau + h > 1:  error in summary.rq")
-    if(tau - h < 0)
-       stop("tau - h < 0:  error in summary.rq")
+    while((tau - h < 0) || (tau + h > 1)) h <- h/2
     h <- (qnorm(tau + h) - qnorm(tau - h)) * max(ztol,min(sqrt(var(uhat)),
         (quantile(uhat, 0.75) - quantile(uhat, 0.25))/1.34))
     f <- c(dnorm(uhat/h)/h,rep(1, length(resid) - n))
